@@ -19,30 +19,16 @@ import sphinx
 from six import StringIO
 from sphinx_testing.path import path
 from sphinx_testing.tmpdir import mkdtemp
-from sphinx_testing.util import ListOutput, TestApp, with_app
+from sphinx_testing.util import TestApp, with_app
 
 
 class TestSphinxTesting(unittest.TestCase):
-    def test_ListOutput(self):
-        output = ListOutput('name')
-        self.assertEqual('name', output.name)
-        self.assertEqual([], output.content)
-
-        output.write('Hello')
-        self.assertEqual(['Hello'], output.content)
-
-        output.write('World')
-        self.assertEqual(['Hello', 'World'], output.content)
-
-        output.reset()
-        self.assertEqual([], output.content)
-
     def test_TestApp(self):
         try:
             srcdir = path(__file__).dirname() / 'examples'
             app = TestApp(srcdir=srcdir)
             self.assertIsInstance(app._status, StringIO)
-            self.assertIsInstance(app._warning, ListOutput)
+            self.assertIsInstance(app._warning, StringIO)
 
             if sphinx.__version__ < '1.0.0':
                 app.build(True, None)
@@ -173,11 +159,18 @@ class TestSphinxTesting(unittest.TestCase):
 
         self.assertFalse(tmpdir.exists())
 
-    def test_with_app_write_docstring1(self):
-        srcdir = path(__file__).dirname() / 'examples'
+    def test_with_app_write_docstring(self):
+        @with_app(create_new_srcdir=True, write_docstring=True)
+        def execute(app, status, warning):
+            """ Hello world """
+            content = (app.srcdir / 'contents.rst').read_text()
+            self.assertEqual('Hello world ', content)
 
-        @with_app(srcdir=srcdir, copy_srcdir_to_tmpdir=True,
-                  write_docstring=True)
+        execute()
+
+    def test_with_app_write_docstring_with_master_doc(self):
+        @with_app(create_new_srcdir=True, write_docstring=True,
+                  confoverrides={'master_doc': 'index'})
         def execute(app, status, warning):
             """ Hello world """
             content = (app.srcdir / 'index.rst').read_text()
@@ -185,11 +178,18 @@ class TestSphinxTesting(unittest.TestCase):
 
         execute()
 
-    def test_with_app_write_docstring2(self):
-        srcdir = path(__file__).dirname() / 'examples'
+    def test_with_app_write_docstring_with_source_suffix(self):
+        @with_app(create_new_srcdir=True, write_docstring=True,
+                  confoverrides={'source_suffix': '.txt'})
+        def execute(app, status, warning):
+            """ Hello world """
+            content = (app.srcdir / 'contents.txt').read_text()
+            self.assertEqual('Hello world ', content)
 
-        @with_app(srcdir=srcdir, copy_srcdir_to_tmpdir=True,
-                  write_docstring='hello.rst')
+        execute()
+
+    def test_with_app_write_docstring_by_name(self):
+        @with_app(create_new_srcdir=True, write_docstring='hello.rst')
         def execute(app, status, warning):
             """ Hello world """
             content = (app.srcdir / 'hello.rst').read_text()
